==> nextcloud-13.0.1.tgz: nextcloud/apps/comments/l10n/ka_GE.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "კომენტარები",
    "New comment …" : "ახალი კომენტარი ...",
    "Delete comment" : "კომენტარის გაუქმება",
    "Post" : "პოსტი",
    "Cancel" : "უარყოფა",
    "Edit comment" : "კომენტარის ცვლილება",
    "[Deleted user]" : "[გაუქმებული მომხმარებელი]",
    "No comments yet, start the conversation!" : "ჯერ კომენტარები არაა, დაიწყეთ საუბარი! ",
    "More comments …" : "მეტი კომენტარი ...",
    "Save" : "შენახვა",
    "Allowed characters {count} of {max}" : "დაშვებული სიმბოლოები {count} {max}-იდან",
    "Error occurred while updating comment with id {id}" : "კომენტარის id-იდ {id}-ის ცვლილებისას წარმოიშვა შეცდომა",
    "Error occurred while posting comment" : "კომენტარის გამოქვეყნებისას წარმოიშვა შეცდომა",
    "_%n unread comment_::_%n unread comments_" : ["%n წაუკუთხავი კომენტარი"],
    "Comment" : "კომენტარის დამატება",
    "You commented" : "თქვენ გააკეთეთ კომენტარი",
    "%1$s commented" : "%1$s მოხმარებელმა გააკეთა კომენტარი",
    "{author} commented" : "{author} მომხმარებელმა გააკეთა კომენტარი",
    "You commented on %1$s" : "თქვენ გააკეთეთ კომენტარი %1$s-ზე",
    "You commented on {file}" : "თქვენ გააკეთეთ კომენტარი {file}-ზე",
    "%1$s commented on %2$s" : "%1$s მომხმარებელმა გააკეთა კომენტარი %2$s-ზე",
    "{author} commented on {file}" : "{author} მომხმარებელმა გააკეთა კომენტარი {file}-ზე",
    "<strong>Comments</strong> for files" : "<strong>კომენტარები</strong> ფაილებზე",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "თქვენ მოგიხსენიეს “%s”-ში, ახლა უკვე გაუქმებული მომხმარებლის კომენტარში",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "თქვენ მოგიხსენიეს “{file}”-ში, ახლა უკვე გაუქმებული მომხმარებლის კომენტარში",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s გახსენათ  “%2$s”-ზე გაკეთებულ კომენტარში",
    "{user} mentioned you in a comment on “{file}”" : "{user} გახსენათ “{file}” ფაილზე გაკეტებულ კომენტარში",
    "Unknown user" : "უცნობი მომხმარებელი",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(ახლა) წაშლილმა მოხმარებელმა მოგიხსენიათ კომენტარში “%s”-ზე",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(ახლა) წაშლილმა მოხმარებელმა მოგიხსენიათ კომენტარში ფაილზე \"{file}\""
},
"nplurals=1; plural=0;");

==> nextcloud-14.0.1.tgz: nextcloud/apps/comments/l10n/ka_GE.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "კომენტარის ცვლილება",
    "Delete comment" : "კომენტარის გაუქმება",
    "New comment …" : "ახალი კომენტარი ...",
    "Post" : "პოსტი",
    "Cancel" : "უარყოფა",
    "[Deleted user]" : "[გაუქმებული მომხმარებელი]",
    "Comments" : "კომენტარები",
    "No comments yet, start the conversation!" : "ჯერ კომენტარები არაა, დაიწყეთ საუბარი! ",
    "More comments …" : "მეტი კომენტარი ...",
    "Save" : "შენახვა",
    "Allowed characters {count} of {max}" : "დაშვებული სიმბოლოები {count} {max}-იდან",
    "Error occurred while updating comment with id {id}" : "კომენტარის id-იდ {id}-ის ცვლილებისას წარმოიშვა შეცდომა",
    "Error occurred while posting comment" : "კომენტარის გამოქვეყნებისას წარმოიშვა შეცდომა",
    "_%n unread comment_::_%n unread comments_" : ["%n წაუკუთხავი კომენტარი","%n წაუკუთხავი კომენტარი"],
    "Comment" : "კომენტარის დამატება",
    "You commented" : "თქვენ გააკეთეთ კომენტარი",
    "%1$s commented" : "%1$s მოხმარებელმა გააკეთა კომენტარი",
    "{author} commented" : "{author} მომხმარებელმა გააკეთა კომენტარი",
    "You commented on %1$s" : "თქვენ გააკეთეთ კომენტარი %1$s-ზე",
    "You commented on {file}" : "თქვენ გააკეთეთ კომენტარი {file}-ზე",
    "%1$s commented on %2$s" : "%1$s მომხმარებელმა გააკეთა კომენტარი %2$s-ზე",
    "{author} commented on {file}" : "{author} მომხმარებელმა გააკეთა კომენტარი {file}-ზე",
    "<strong>Comments</strong> for files" : "<strong>კომენტარები</strong> ფაილებზე",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "თქვენ მოგიხსენიეს “%s”-ში, ახლა უკვე გაუქმებული მომხმარებლის კომენტარში",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "თქვენ მოგიხსენიეს “{file}”-ში, ახლა უკვე გაუქმებული მომხმარებლის კომენტარში",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s გახსენათ  “%2$s”-ზე გაკეთებულ კომენტარში",
    "{user} mentioned you in a comment on “{file}”" : "{user} გახსენათ “{file}” ფაილზე გაკეტებულ კომენტარში",
    "Unknown user" : "უცნობი მომხმარებელი",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(ახლა) წაშლილმა მოხმარებელმა მოგიხსენიათ კომენტარში “%s”-ზე",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(ახლა) წაშლილმა მოხმარებელმა მოგიხსენიათ კომენტარში ფაილზე \"{file}\""
},
"nplurals=2; plural=(n!=1);");
